==> amazon_reports_downloader-0.0.45-py2.py3-none-any.whl: amazon_reports_downloader/bin/disburse.py <==
# -*- coding: utf-8 -*-

# Copyright :copyright: 2019 by IBPort. All rights reserved.
# @Author: Neal Wong
# @Email: ibprnd@gmail.com

import asyncio
import os
import sys
import logging
import logging.handlers

import click
import sentry_sdk

from amazon_reports_downloader.config_loaders import YamlConfigLoader
from amazon_reports_downloader.exchange_rate import EcbExchangeRate

from amazon_reports_downloader import logger
from amazon_reports_downloader.disburse_task_v2 import DisburseTaskV2
import datetime
import time
import pytz
chicagoTz = pytz.timezone("America/Chicago") 

@click.command()
@click.option('-c', '--config_path', help='Configuration file path.')
def disburse(config_path):
    if sys.platform.startswith('win'):
        work_dir = 'C:\\AmazonReportDownloader'
    else:
        work_dir = os.path.join(os.path.expanduser('~'), '.AmazonReportDownloader')

    log_dir = os.path.join(work_dir, 'logs')
    if not os.path.isdir(log_dir):
        os.makedirs(log_dir)

    log_path = os.path.join(log_dir, 'disburse.log')
    level = logging.INFO
    max_bytes = 100 * 1024 ** 2
    fh = logging.handlers.RotatingFileHandler(
        log_path, maxBytes=max_bytes, backupCount=5)
    fh.setLevel(level)
    formatter = logging.Formatter('%(asctime)s %(name)s [%(levelname)s]:%(message)s')
    fh.setFormatter(formatter)
    logger.addHandler(fh)

    if not config_path:
        logger.error('config_path is required to run!')
        sys.exit(1)

    config_path = os.path.abspath(os.path.expanduser(config_path))
    if not os.path.isfile(config_path):
        logger.error('Could not find configuration file - %s', config_path)
        sys.exit(0)

    cl = YamlConfigLoader(config_path)
    config = cl.load()

    if 'account' not in config or not config['account']:
        logger.error('Could not find "account" configuration!')
        sys.exit(0)

    seller_id = config['account']['seller_id']
    code = str(config['account']['acc'])
    domain = config['account']['domain']
    marketplaces = config['account']['marketplace']
    min_disburse_amount = 200
    exchange_rate = EcbExchangeRate()
    rates = exchange_rate.get_exchange_rate('USD')
    email = config['account']['email']
    password = config['account']['password']

    sheet_id = config['account']['sheet_id'] if "sheet_id" in config['account'] else "1b8wHMP05Na4ELcyP5Jn9syb9g6uMc8FkBTsckOCIz7w"
 
    now = datetime.datetime.now(chicagoTz)
    start_time = datetime.datetime.strptime(str(datetime.datetime.now(chicagoTz).date()) + '0:00', '%Y-%m-%d%H:%M').replace(tzinfo=chicagoTz)
    end_time = datetime.datetime.strptime(str(datetime.datetime.now(chicagoTz).date()) + '23:59', '%Y-%m-%d%H:%M').replace(tzinfo=chicagoTz)

    block_start_time = chicagoTz.localize(datetime.datetime(2023, 10, 7, 0, 0, 0))
    block_end_time = chicagoTz.localize(datetime.datetime(2023, 10, 8, 0, 0, 0))

    if now > block_start_time and now < block_end_time:
        logger.info(f"Do not need to disburse during {block_start_time} -- {block_end_time}")
        return

    if now > start_time and now < end_time:
        for marketplace in marketplaces:
            try:
                sentry_sdk.set_context("Account", {
                    "name": "{}-{}".format(seller_id or code, marketplace),
                })
            except:
                pass

            disburse_task = DisburseTaskV2(
                seller_id, marketplace, email, password, domain, rates, min_disburse_amount,
                sheet_id, code, chicagoTz
            )
            try:
                asyncio.get_event_loop().run_until_complete(disburse_task.run())
            except Exception as e:
                logger.exception(e)


if __name__ == '__main__':
    disburse()

==> amazon_reports_downloader-0.0.48-py2.py3-none-any.whl: amazon_reports_downloader/bin/disburse.py <==
# -*- coding: utf-8 -*-

# Copyright :copyright: 2019 by IBPort. All rights reserved.
# @Author: Neal Wong
# @Email: ibprnd@gmail.com

import asyncio
import os
import sys
import logging
import logging.handlers

import click
import sentry_sdk

from amazon_reports_downloader.config_loaders import YamlConfigLoader
from amazon_reports_downloader.exchange_rate import EcbExchangeRate

from amazon_reports_downloader import logger
from amazon_reports_downloader.disburse_task_v2 import DisburseTaskV2
import datetime
import time
import pytz
chicagoTz = pytz.timezone("America/Chicago") 

@click.command()
@click.option('-c', '--config_path', help='Configuration file path.')
@click.option('-s', '--service_account_path', help='Google service account file path.')
def disburse(config_path, service_account_path):
    if sys.platform.startswith('win'):
        work_dir = 'C:\\AmazonReportDownloader'
    else:
        work_dir = os.path.join(os.path.expanduser('~'), '.AmazonReportDownloader')

    log_dir = os.path.join(work_dir, 'logs')
    if not os.path.isdir(log_dir):
        os.makedirs(log_dir)

    log_path = os.path.join(log_dir, 'disburse.log')
    level = logging.INFO
    max_bytes = 100 * 1024 ** 2
    fh = logging.handlers.RotatingFileHandler(
        log_path, maxBytes=max_bytes, backupCount=5)
    fh.setLevel(level)
    formatter = logging.Formatter('%(asctime)s %(name)s [%(levelname)s]:%(message)s')
    fh.setFormatter(formatter)
    logger.addHandler(fh)

    if not config_path:
        logger.error('config_path is required to run!')
        sys.exit(1)

    config_path = os.path.abspath(os.path.expanduser(config_path))
    if not os.path.isfile(config_path):
        logger.error('Could not find configuration file - %s', config_path)
        sys.exit(0)

    cl = YamlConfigLoader(config_path)
    config = cl.load()

    if 'account' not in config or not config['account']:
        logger.error('Could not find "account" configuration!')
        sys.exit(0)

    seller_id = config['account']['seller_id']
    code = str(config['account']['acc'])
    domain = config['account']['domain']
    marketplaces = config['account']['marketplace']
    min_disburse_amount = 200
    exchange_rate = EcbExchangeRate()
    rates = exchange_rate.get_exchange_rate('USD')
    email = config['account']['email']
    password = config['account']['password']

    sheet_id = config['account']['sheet_id'] if "sheet_id" in config['account'] else "1b8wHMP05Na4ELcyP5Jn9syb9g6uMc8FkBTsckOCIz7w"
 
    now = datetime.datetime.now(chicagoTz)
    start_time = datetime.datetime.strptime(str(datetime.datetime.now(chicagoTz).date()) + '0:00', '%Y-%m-%d%H:%M').replace(tzinfo=chicagoTz)
    end_time = datetime.datetime.strptime(str(datetime.datetime.now(chicagoTz).date()) + '23:59', '%Y-%m-%d%H:%M').replace(tzinfo=chicagoTz)

    block_start_time = chicagoTz.localize(datetime.datetime(2023, 10, 7, 0, 0, 0))
    block_end_time = chicagoTz.localize(datetime.datetime(2023, 10, 8, 0, 0, 0))

    if now > block_start_time and now < block_end_time:
        logger.info(f"Do not need to disburse during {block_start_time} -- {block_end_time}")
        return

    if now > start_time and now < end_time:
        for marketplace in marketplaces:
            try:
                sentry_sdk.set_context("Account", {
                    "name": "{}-{}".format(seller_id or code, marketplace),
                })
            except:
                pass

            disburse_task = DisburseTaskV2(
                seller_id, marketplace, email, password, domain, rates, min_disburse_amount,
                sheet_id, code, chicagoTz, service_account_path
            )
            try:
                asyncio.get_event_loop().run_until_complete(disburse_task.run())
            except Exception as e:
                logger.exception(e)


if __name__ == '__main__':
    disburse()
